┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/treeviewcontextmenu.h
diff options
context:
space:
mode:
authorPeter Penz <[email protected]>2008-03-23 15:51:30 +0000
committerPeter Penz <[email protected]>2008-03-23 15:51:30 +0000
commit99419d3d74b1aa6667dfb5132d0122779ebdb5aa (patch)
treefd12495647face1bbe41e778b39e6ab069e919dd /src/treeviewcontextmenu.h
parentacb61c69a6191bee82bb87f04153300ab0c86859 (diff)
allow to show hidden files in the Folders panel (treeview)
svn path=/trunk/KDE/kdebase/apps/; revision=789206
Diffstat (limited to 'src/treeviewcontextmenu.h')
-rw-r--r--src/treeviewcontextmenu.h14
1 files changed, 11 insertions, 3 deletions
diff --git a/src/treeviewcontextmenu.h b/src/treeviewcontextmenu.h
index a8dfac126..ec6170bf2 100644
--- a/src/treeviewcontextmenu.h
+++ b/src/treeviewcontextmenu.h
@@ -23,6 +23,8 @@
#include <QtCore/QObject>
#include <KFileItem>
+class TreeViewSidebarPage;
+
/**
* @brief Represents the context menu which appears when doing a right
* click on an item of the treeview.
@@ -33,13 +35,13 @@ class TreeViewContextMenu : public QObject
public:
/**
* @parent Pointer to the parent widget the context menu
* belongs to.
* @fileInfo Pointer to the file item the context menu
* is applied. If 0 is passed, the context menu
* is above the viewport.
*/
- TreeViewContextMenu(QWidget* parent,
+ TreeViewContextMenu(TreeViewSidebarPage* parent,
const KFileItem& fileInfo);
virtual ~TreeViewContextMenu();
@@ -69,8 +71,14 @@ private slots:
/** Shows the properties of the item m_fileInfo. */
void showProperties();
+ /**
+ * Sets the 'Show Hidden Files' setting for the
+ * folders panel to \a show.
+ */
+ void setShowHiddenFiles(bool show);
+
private:
- QWidget* m_parent;
+ TreeViewSidebarPage* m_parent;
KFileItem m_fileInfo;
};
@@ -33,13 +35,13 @@ class TreeViewContextMenu : public QObject
public:
/**
- * @parent Pointer to the parent widget the context menu
+ * @parent Pointer to the treeview sidebar page the context menu
* belongs to.
* @fileInfo Pointer to the file item the context menu